Afbeeldingen invoegen

Afbeeldingen invoegen | Inhoudsopgave

Voer simpelweg de URL van de afbeelding en de beschrijving in. De omschrijvende tekst wordt in sommige browsers bij de muiswijzer getoond wanneer deze boven de afbeelding wordt stilgehouden. De knop 'Afbeelding Invoegen' opent onderstaand dialoogvenster.
Omschrijving van de velden:

Afbeelding | In dit veld dient u een complete URL op te geven van de afbeelding.
Beschrijving | Omschrijvende tekst die in sommige browsers bij de muiswijzer wordt getoond wanneer deze boven de afbeelding wordt stilgehouden.
Uitlijning | Uit de lijst kan worden gekozen op welke wijze de afbeelding in de tekst wordt ingebed.
Afmetingen | De breedte en hoogte van de afbeelding in pixels. Laat deze velden leeg als de originele afmetingen gewenst zijn.
Omranding | De dikte (in pixels) van de omranding om de afbeelding.
Verticale marge | De verticale marge (in pixels) gebruikt voor de omloop van teksten om de afbeelding.
Horizontale marge | De horizontale marge (in pixels) gebruikt voor de omloop van teksten om de afbeelding.

Ga naar: Inhoudsopgave | Naar boven